@@ -44,7 +44,7 @@ use PPIx::Regexp;
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.020';
+our $VERSION = '0.041';
 
 =head2 new
 
@@ -63,6 +63,12 @@ The following options are recognized:
 
 =over
 
+=item default_modifiers array_reference
+
+This argument is a reference to a list of default modifiers to be
+applied to the statement being parsed. See L<PPIx::Regexp|PPIx::Regexp>
+L<new()|PPIx::Regexp/new> for the details.
+
 =item encoding name
 
 This argument is the name of the encoding of the regular expression. If
@@ -169,6 +175,9 @@ ignored.
 	    source => $re,
 	};
 
+	exists $args{default_modifiers}
+	    and $self->{default_modifiers} = $args{default_modifiers};
+
 	foreach my $key ( keys %default ) {
 	    $self->{$key} = exists $args{$key} ?
 		delete $args{$key} :
@@ -329,6 +338,15 @@ sub _tokens_dump {
     return @rslt;
 }
 
+sub _format_default_modifiers {
+    my ( $self, $subr, $elem ) = @_;
+    my $default_modifiers = $self->{default_modifiers} || [];
+    @{ $default_modifiers }
+	or return sprintf '%-8s( %s );', $subr, $self->_safe( $elem );
+    return sprintf '%-8s( %s, default_modifiers => %s );', $subr,
+	$self->_safe( $elem ), $self->_safe( $default_modifiers );
+}
+
 sub _format_modifiers_dump {
     my ( $self, $elem ) = @_;
     my %mods = $elem->modifiers();
@@ -350,10 +368,12 @@ sub _tokens_test {
     not $self->{significant} or $elem->significant() or return;
 
     my @tokens = $elem->tokens();
+
     my @rslt = (
-	'tokenize( ' . $self->_safe( $elem ) . ' );',
-	'count   ( ' . scalar @tokens . ' );',
+	$self->_format_default_modifiers( tokenize => $elem ),
+	sprintf( 'count   ( %d );', scalar @tokens ),
     );
+
     my $inx = 0;
     foreach my $token ( @tokens ) {
 	not $self->{significant} or $token->significant() or next;
@@ -370,7 +390,8 @@ sub PPIx::Regexp::__PPIX_DUMPER__test {
 
     not $dumper->{significant} or $self->significant() or return;
 
-    my $parse = 'parse   ( ' . $dumper->_safe( $self ) . ' );';
+#   my $parse = 'parse   ( ' . $dumper->_safe( $self ) . ' );';
+    my $parse = $dumper->_format_default_modifiers( parse => $self );
     my $fail =  'value   ( failures => [], ' . $self->failures() . ' );';
 
     # Note that we can not use SUPER in the following because SUPER goes
@@ -393,7 +414,10 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__dump {
 
     my @rslt = ref $self;
     $self->isa( 'PPIx::Regexp' )
-	and $rslt[-1] .= "\tfailures=" . $self->failures();
+	and $rslt[-1] .= $dumper->{verbose}
+	    ? sprintf "\tfailures=%d\tmax_capture_number=%d",
+		$self->failures(), $self->max_capture_number()
+	    : sprintf "\tfailures=%d", $self->failures();
     $dumper->{perl_version}
 	and $rslt[-1] .= "\t" . $dumper->_perl_version( $self );
     my $indent = ' ' x $dumper->{indent};
@@ -429,6 +453,16 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
     return @rslt;
 }
 
+sub _format_value {
+    my ( $val ) = @_;
+    defined $val
+	or return 'undef';
+    $val =~ m/ \A [0-9]+ \z /smx
+	and return $val;
+    $val =~ s/ (?= [\\"] ) /\\/smxg;
+    return qq{"$val"};
+}
+
 {
 
     my %dflt = (
@@ -452,14 +486,13 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 	$dumper->{perl_version}
 	    and push @rslt, $dumper->_perl_version( $self );
 	if ( $dumper->{verbose} ) {
-	    foreach my $method ( qw{ number name } ) {
+	    foreach my $method ( qw{ number name max_capture_number } ) {
 		$self->can( $method ) or next;
-		my $val = $self->$method;
-		push @rslt, defined $val ?
-		    "$method=$val" :
-		    "$method undef";
+		push @rslt, sprintf '%s=%s', $method, _format_value(
+		    $self->$method() );
 	    }
 	    foreach my $method ( qw{ can_be_quantified is_quantifier } ) {
+##		is_case_sensitive
 		$self->can( $method ) or next;
 		$self->$method() and push @rslt, $method;
 	    }
@@ -534,27 +567,47 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
     not $dumper->{significant} or $self->significant() or return;
 
     my @rslt = ( ref $self, $dumper->_safe( $self ) );
-    $dumper->{perl_version}
-	and push @rslt, $dumper->_perl_version( $self );
-    if ( $dumper->{ordinal} && $self->can( 'ordinal' )
-	&& defined ( my $ord = $self->ordinal() ) ) {
-	push @rslt, sprintf '0x%02x', $ord;
-    }
-    if ( $dumper->{verbose} ) {
-	if ( $self->isa( 'PPIx::Regexp::Token::Reference' ) ) {
-	    foreach my $method ( qw{ absolute name number } ) {
-		defined( my $val = $self->$method() ) or next;
-		push @rslt, "$method=$val";
+
+    if ( defined( my $err = $self->error() ) ) {
+
+	push @rslt, $err;
+
+    } else {
+
+	$dumper->{perl_version}
+	    and push @rslt, $dumper->_perl_version( $self );
+
+	if ( $dumper->{ordinal} && $self->can( 'ordinal' )
+	    && defined ( my $ord = $self->ordinal() ) ) {
+	    push @rslt, sprintf '0x%02x', $ord;
+	}
+
+	if ( $dumper->{verbose} ) {
+
+	    if ( $self->isa( 'PPIx::Regexp::Token::Reference' ) ) {
+		foreach my $method ( qw{ absolute name number } ) {
+		    defined( my $val = $self->$method() ) or next;
+		    push @rslt, "$method=$val";
+		}
 	    }
-	}
-	foreach my $method (
-	    qw{significant can_be_quantified is_quantifier } ) {
-	    $self->$method() and push @rslt, $method;
-	}
-	if ( $self->isa( 'PPIx::Regexp::Token::Modifier' ) ||
-	    $self->isa( 'PPIx::Regexp::Token::GroupType::Modifier' )
-	) {
-	    push @rslt, $dumper->_format_modifiers_dump( $self );
+
+	    foreach my $method (
+		qw{ significant can_be_quantified is_quantifier } ) {
+##		is_case_sensitive
+		$self->can( $method )
+		    and $self->$method()
+		    and push @rslt, $method;
+	    }
+
+	    $self->can( 'ppi' )
+		and push @rslt, $self->ppi()->content();
+
+	    if ( $self->isa( 'PPIx::Regexp::Token::Modifier' ) ||
+		$self->isa( 'PPIx::Regexp::Token::GroupType::Modifier' )
+	    ) {
+		push @rslt, $dumper->_format_modifiers_dump( $self );
+	    }
+
 	}
     }
     return join( "\t", @rslt );
@@ -571,23 +624,42 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'content ( ' . $dumper->_safe( $self ) . ' );',
     );
-    if ( $dumper->{perl_version} ) {
-	foreach my $method ( qw{
-	    perl_version_introduced
-	    perl_version_removed
-	} ) {
-	    push @rslt, "value   ( $method => [], " .
-		$dumper->_safe_version( $self->$method() ) . ' );';
+
+    if ( defined( my $err = $self->error() ) ) {
+
+	push @rslt,
+	    'error   ( ' . $dumper->_safe( $err ) . ' );';
+
+    } else {
+
+	if ( $dumper->{perl_version} ) {
+	    foreach my $method ( qw{
+		perl_version_introduced
+		perl_version_removed
+	    } ) {
+		push @rslt, "value   ( $method => [], " .
+		    $dumper->_safe_version( $self->$method() ) . ' );';
+	    }
 	}
-    }
-    if ( $dumper->{verbose} ) {
-	foreach my $method (
-	    qw{significant can_be_quantified is_quantifier } ) {
-	    push @rslt, $self->$method() ?
-	        "true    ( $method => [] );" :
-	        "false   ( $method => [] );";
+
+	if ( $dumper->{verbose} ) {
+
+	    foreach my $method (
+		qw{ significant can_be_quantified is_quantifier } ) {
+##		is_case_sensitive
+		$self->can( $method ) or next;
+		push @rslt, $self->$method() ?
+		    "true    ( $method => [] );" :
+		    "false   ( $method => [] );";
+	    }
+
+	    $self->can( 'ppi' )
+		and push @rslt, "value   ( ppi => [], " .
+		    $dumper->_safe( $self->ppi() ) . ' );';
+
 	}
     }
+
     return @rslt;
 }
 
@@ -606,7 +678,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
