@@ -13,7 +13,8 @@ PPIx::Regexp::Token::CharClass::POSIX - Represent a POSIX character class
 C<PPIx::Regexp::Token::CharClass::POSIX> is a
 L<PPIx::Regexp::Token::CharClass|PPIx::Regexp::Token::CharClass>.
 
-C<PPIx::Regexp::Token::CharClass::POSIX> has no descendants.
+C<PPIx::Regexp::Token::CharClass::POSIX> is the parent of
+L<PPIx::Regexp::Token::CharClass::POSIX::Unknown|PPIx::Regexp::Token::CharClass::POSIX::Unknown>.
 
 =head1 DESCRIPTION
 
@@ -23,13 +24,13 @@ recognized within a character class.
 Note that collating symbols (e.g. C<[.ch.]>) and equivalence classes
 (e.g. C<[=a=]>) are valid in the POSIX standard, but are not valid in
 Perl regular expressions. These end up being represented by
-L<PPIx::Regexp::Token::CharClass::Posix::Unknown|PPIx::Regexp::Token::CharClass::Posix::Unknown>,
+L<PPIx::Regexp::Token::CharClass::POSIX::Unknown|PPIx::Regexp::Token::CharClass::POSIX::Unknown>,
 and are considered a parse failure.
 
 =head1 METHODS
 
-This class provides no public methods beyond those provided by its
-superclass.
+This class provides the following public methods beyond those provided
+by its superclass.
 
 =cut
 
@@ -40,13 +41,30 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::CharClass };
 
-use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.020';
+our $VERSION = '0.041';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+##=head2 is_case_sensitive
+##
+##This override of the superclass method of the same name returns true if
+##the character class is C<[:lower:]> or C<[:upper:]>, and false (but
+##defined) for all other POSIX character classes.
+##
+##=cut
+##
+##{
+##    my %case_sensitive = map { $_ => 1 } qw{ [:lower:] [:upper:] };
+##
+##    sub is_case_sensitive {
+##	my ( $self ) = @_;
+##	return $case_sensitive{ $self->content() } || 0;
+##    }
+##}
+
 sub perl_version_introduced {
 #   my ( $self ) = @_;
     return '5.006';
@@ -61,7 +79,9 @@ sub perl_version_introduced {
     sub __PPIX_TOKENIZER__regexp {
 	my ( $class, $tokenizer, $character ) = @_;
 
-	$tokenizer->cookie( COOKIE_CLASS ) or return;
+	$tokenizer->cookie( COOKIE_CLASS )
+	    or $tokenizer->cookie( COOKIE_REGEX_SET )
+	    or return;
 
 	if ( my $accept = $tokenizer->find_regexp(
 		qr{ \A [[] ( [.=:] ) \^? .*? \1 []] }smx ) ) {
@@ -91,7 +111,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
