@@ -45,7 +45,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_QUOTE MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.034';
+our $VERSION = '0.041';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -92,7 +92,10 @@ sub __PPIX_TOKENIZER__regexp {
     # do. If there is no next character, we do not know what to call the
     # back slash.
     my $control = $tokenizer->peek( 1 )
-	or return $reject->( 1, TOKEN_UNKNOWN );
+	or return $reject->( 1, TOKEN_UNKNOWN, {
+		error => 'Trailing back slash'
+	    },
+	);
 
     # We reject any escapes that do not represent controls.
     $is_control{$control} or return $reject->( 2 );
@@ -135,7 +138,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
