@@ -35,9 +35,11 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::Code };
 
 use PPI::Document;
-use PPIx::Regexp::Constant qw{ COOKIE_CLASS TOKEN_LITERAL MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{
+    COOKIE_CLASS COOKIE_REGEX_SET TOKEN_LITERAL MINIMUM_PERL
+};
 
-our $VERSION = '0.020';
+our $VERSION = '0.041';
 
 # Return true if the token can be quantified, and false otherwise
 # This can be quantified because it might interpolate a quantifiable
@@ -46,13 +48,14 @@ our $VERSION = '0.020';
 
 # We overrode this in PPIx::Regexp::Token::Code, since (?{...}) did not
 # appear until Perl 5.5. But interpolation has been there since the
-# beginning, so we have to override again. Sigh.
+# beginning, so we have to override again. This turns out to be OK,
+# though, because while Regex Sets were introduced in 5.17.8,
+# interpolation inside them was not introduced until 5.17.9.
 sub perl_version_introduced {
-#   my ( $self ) = @_;
-    return MINIMUM_PERL;
+    my ( $self ) = @_;
+    return $self->{perl_version_introduced};
 }
 
-
 =head2 ppi
 
 This convenience method returns the L<PPI::Document|PPI::Document>
@@ -63,8 +66,8 @@ not be the same as the content of the original
 C<PPIx::Regexp::Token::Interpolation>. This can happen because
 interpolated variable names may be enclosed in curly brackets, but this
 does not happen in normal code. For example, in C</${foo}bar/>, the
-content of the C<PPIx> object will be C<'${foo}'>, but the content of
-the C<PPI::Document> will be C<'$foo'>.
+content of the C<PPIx::Regexp::Token::Interpolation> object will be
+C<'${foo}'>, but the content of the C<PPI::Document> will be C<'$foo'>.
 
 =cut
 
@@ -86,7 +89,7 @@ sub ppi {
 # Match the beginning of an interpolation.
 
 my $interp_re =
-	qr{ \A (?: [\@\$]? \$ [-\w&`'+^./\\";%=~:?!\@\$<>\[\]\{\},#] |
+	qr{ \A (?= [\@\$]? \$ [-\w&`'+^./\\";%=~:?!\@\$<>\[\]\{\},#] |
 		   \@ [\w\{] )
 	}smx;
 
@@ -119,8 +122,8 @@ sub _interpolation {
 	return $len;
     }
 
-    # Make sure we start off plausably
-    $tokenizer->find_regexp( $interp_re )
+    # Make sure we start off plausibly
+    defined $tokenizer->find_regexp( $interp_re )
 	or return;
 
     # See if PPI can figure out what we have
@@ -277,11 +280,17 @@ sub _curly {
 	    and return 1;
     }
 
-    # If we have exactly one child which is a symbol, we accept it as a
-    # subscript.
-    @kids == 1
-	and $kids[0]->isa( 'PPI::Token::Symbol' )
-	and return 1;
+    # If the first child is a symbol,
+    if ( @kids && $kids[0]->isa( 'PPI::Token::Symbol' ) ) {
+	# Accept it if it is the only child
+	@kids == 1
+	    and return 1;
+	# Accept it if there are exactly two children and the second is
+	# a subscript.
+	@kids == 2
+	    and $kids[1]->isa( 'PPI::Structure::Subscript' )
+	    and return 1;
+    }
 
     # We reject anything else.
     return;
@@ -301,6 +310,28 @@ sub _square {
     return;
 }
 
+{
+
+    my %default = (
+	perl_version_introduced	=> MINIMUM_PERL,
+    );
+
+    sub __PPIX_TOKEN__post_make {
+	my ( $self, $tokenizer, $arg ) = @_;
+
+	# If we're manufacturing objects directly (which is UNSUPPORTED,
+	# but used in t/version.t) we may not have a $tokenizer.
+	$tokenizer
+	    and $tokenizer->cookie( COOKIE_REGEX_SET )
+	    and $self->{perl_version_introduced} = '5.017009';
+
+	$self->__impose_defaults( $arg, \%default );
+
+	return;
+    }
+
+}
+
 # Alternate classes for the sigils, depending on whether we are in a
 # character class (index 1) or not (index 0).
 my %sigil_alternate = (
@@ -415,7 +446,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
