@@ -37,7 +37,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.020';
+our $VERSION = '0.041';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -56,6 +56,18 @@ sub ordinal {
     return ord $self->content();
 }
 
+sub __PPIX_TOKEN__post_make {
+    my ( $self, $tokenizer, $arg ) = @_;
+    my $msg = $arg->{error};
+    use Carp;
+    defined $msg
+	or Carp::cluck( 'Making unknown token with no error message' );
+    defined $msg
+	or $msg = 'Unspecified error';
+    $self->{error} = $msg;
+    return;
+}
+
 # Since the lexer does not count these on the way in (because it needs
 # the liberty to rebless them into a known class if it figures out what
 # is going on) we count them as failures at the finalization step.
@@ -78,7 +90,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
